@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2000, 2003, 2004 SuSE GmbH Nuernberg, Germany.
+ * Copyright (c) 2000, 2003, 2004, 2005 SuSE GmbH Nuernberg, Germany.
  * Author: Thorsten Kukuk <kukuk@suse.de>
  *
  * Redistribution and use in source and binary forms, with or without
@@ -421,7 +421,7 @@ update_npd (nis_object *obj, user_t *data, pam_handle_t *pamh, int flags)
   if (clnt == NULL)
     {
       __write_message (pamh, flags, PAM_ERROR_MSG,
-		       _("rpc.nispasswd not running on %s ?"), masterhost);
+		       _("rpc.nispasswd not running on %s?"), masterhost);
       return -1;
     }
   memset ((char *) &result, 0, sizeof (result));
@@ -604,9 +604,7 @@ update_nisd (nis_object *obj, user_t *data, pam_handle_t *pamh, int flags)
 		   _("The NIS+ credential information for %s will not be changed."),
 		   user);
   __write_message (pamh, flags, PAM_TEXT_INFO,
-		   _("User %s must do the following to update his/her"), user);
-  __write_message (pamh, flags, PAM_TEXT_INFO,
-		   _("credential information:"));
+		   _("User %s must do the following to update his/her credential information:"), user);
   __write_message (pamh, flags, PAM_TEXT_INFO,
 		   _("Use NEW password for login and OLD password for keylogin."));
   __write_message (pamh, flags, PAM_TEXT_INFO,
