@@ -686,7 +686,7 @@ __do_setpass (pam_handle_t *pamh, int flags, user_t *data,
       free (salt);
 #else
       __write_message (pamh, flags, PAM_ERROR_MSG,
-		       _("No support for blowfish compiled in"))x;
+		       _("No support for blowfish compiled in"));
       return PAM_AUTHTOK_ERR;
 #endif
       break;
